/** \file enumreference.cpp
 *  \brief This file contains the implementation of the helper class EnumReference.
 *
 *  \par license
 *  The cc1394 viewer application is licensed under the '3-clause'BSD License.
 *  Copyright (C) 2009, Allied Vision Technologies GmbH
 *  All rights reserved.
 *  Address: Taschenweg 2A, 07646 Stadtroda, Germany
 *  Email: info@alliedvisiontec.com
 *  Internet: www.alliedvisiontec.com
 *  Redistribution and use in source and binary forms, with or without modification, are permitted provided 
 *  that the following conditions are met:
 *     1. Redistributions of source code must retain the above copyright notice, this list of conditions and 
 *        the following disclaimer.
 *     2. Redistributions in binary form must reproduce the above copyright notice, this list of conditions 
 *        and the following disclaimer in the documentation and/or other materials provided with the 
 *        distribution.
 *     3. The name of Allied Vision Technologies GmbH may not be used to endorse or promote products derived 
 *        from this software without specific prior written permission.
 *  THIS SOFTWARE IS PROVIDED BY ALLIED VISION TECHNOLOGIES GMBH ''AS IS'' AND ANY EXPRESS OR IMPLIED WARRANTIES, 
 *  INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE 
 *  ARE DISCLAIMED. IN NO EVENT SHALL ALLIED VISION TECHNOLOGIES GMBH BE LIABLE FOR ANY DIRECT, INDIRECT, 
 *  INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF 
 *  SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON 
 *  ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) 
 *  ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */


#include "enumreference.h"


EnumReference::EnumReference()
{
}


EnumReference::~EnumReference()
{
}


const EnumReference::dc1394_mode_entry EnumReference::m_arrModeList[]=
{	{	 DC1394_VIDEO_MODE_160x120_YUV444	, "160x120_YUV444" },
    {	 DC1394_VIDEO_MODE_320x240_YUV422	, "320x240_YUV422" },
	{	 DC1394_VIDEO_MODE_640x480_YUV411	, "640x480_YUV411" },
	{	 DC1394_VIDEO_MODE_640x480_YUV422	, "640x480_YUV422" },
	{	 DC1394_VIDEO_MODE_640x480_RGB8		, "640x480_RGB8"   },
	{	 DC1394_VIDEO_MODE_640x480_MONO8 	, "640x480_MONO8"  },
	{	 DC1394_VIDEO_MODE_640x480_MONO16 	, "640x480_MONO16" },
	{	 DC1394_VIDEO_MODE_800x600_YUV422 	, "800x600_YUV422" },
	{	 DC1394_VIDEO_MODE_800x600_RGB8 	, "800x600_RGB8"   },
	{	 DC1394_VIDEO_MODE_800x600_MONO8 	, "800x600_MONO8"  },
	{	 DC1394_VIDEO_MODE_1024x768_YUV422 	, "1024x768_YUV422"},
	{	 DC1394_VIDEO_MODE_1024x768_RGB8 	, "1024x768_RGB8"  },
	{	 DC1394_VIDEO_MODE_1024x768_MONO8 	, "1024x768_MONO8" },
	{	 DC1394_VIDEO_MODE_800x600_MONO16 	, "800x600_MONO16" },
	{	 DC1394_VIDEO_MODE_1024x768_MONO16 	, "1024x768_MONO16"},
	{	 DC1394_VIDEO_MODE_1280x960_YUV422 	, "1280x960_YUV422"},
	{	 DC1394_VIDEO_MODE_1280x960_RGB8 	, "1280x960_RGB8"  },
	{	 DC1394_VIDEO_MODE_1280x960_MONO8 	, "1280x960_MONO8" },
    {	 DC1394_VIDEO_MODE_1600x1200_YUV422 , "1600x1200_YUV422"   },
	{	 DC1394_VIDEO_MODE_1600x1200_RGB8 	, "1600x1200_RGB8" },
	{	 DC1394_VIDEO_MODE_1600x1200_MONO8 	, "1600x1200_MONO8"},
	{	 DC1394_VIDEO_MODE_1280x960_MONO16 	, "1280x960_MONO16"},
	{	 DC1394_VIDEO_MODE_1600x1200_MONO16 	, "1600x1200_MONO16"   },
	{	 DC1394_VIDEO_MODE_EXIF 		, "EXIF"       	   },
	{	 DC1394_VIDEO_MODE_FORMAT7_0 		, "FORMAT7_0"      },
	{	 DC1394_VIDEO_MODE_FORMAT7_1 		, "FORMAT7_1"      },
	{	 DC1394_VIDEO_MODE_FORMAT7_2 		, "FORMAT7_2"      },
	{	 DC1394_VIDEO_MODE_FORMAT7_3 		, "FORMAT7_3"      },
	{	 DC1394_VIDEO_MODE_FORMAT7_4 		, "FORMAT7_4"      },
	{	 DC1394_VIDEO_MODE_FORMAT7_5 		, "FORMAT7_5"      },
	{	 DC1394_VIDEO_MODE_FORMAT7_6 		, "FORMAT7_6"      },
	{	 DC1394_VIDEO_MODE_FORMAT7_7 		, "FORMAT7_7"      }
};


const EnumReference::dc1394_framerate_entry EnumReference::m_arrRateList[]=
{	{	DC1394_FRAMERATE_1_875	, "1.875" },
	{	DC1394_FRAMERATE_3_75	, "3.75" },
	{	DC1394_FRAMERATE_7_5	, "7.5" },
	{	DC1394_FRAMERATE_15	, "15" },
	{	DC1394_FRAMERATE_30	, "30" },
	{	DC1394_FRAMERATE_60	, "60" },
	{	DC1394_FRAMERATE_120	, "120" },
	{	DC1394_FRAMERATE_240	, "240" },
};


const EnumReference::dc1394_colorcoding_entry EnumReference::m_arrCodingList[]=
{	{	DC1394_COLOR_CODING_MONO8	   , "MONO8"	},
    {	DC1394_COLOR_CODING_YUV411	   , "YUV411"	},
    {	DC1394_COLOR_CODING_YUV422	   , "YUV422"	},
    {	DC1394_COLOR_CODING_YUV444	   , "YUV444"	},
    {	DC1394_COLOR_CODING_RGB8	   , "RGB8"	},
    {	DC1394_COLOR_CODING_MONO16	   , "MONO16"	},
    {	DC1394_COLOR_CODING_RGB16	   , "RGB16"	},
    {	DC1394_COLOR_CODING_MONO16S	   , "MONO16S"	},
    {	DC1394_COLOR_CODING_RGB16S	   , "RGB16S"	},
    {	DC1394_COLOR_CODING_RAW8	   , "RAW8"	},
    {	DC1394_COLOR_CODING_RAW16	   , "RAW16"	},
    {   DC1394_COLOR_CODING_AVT_MONO12 , "MONO12" },
    {   DC1394_COLOR_CODING_AVT_RAW12  , "RAW12" }
};


const EnumReference::dc1394_feature_entry EnumReference::m_arrFeatureList[]=
{  {    DC1394_FEATURE_BRIGHTNESS,      "BRIGHTNESS" },
   {    DC1394_FEATURE_EXPOSURE,        "EXPOSURE" },
   {    DC1394_FEATURE_SHARPNESS,       "SHARPNESS" },
   {    DC1394_FEATURE_WHITE_BALANCE,   "WHITE_BALANCE" },
   {    DC1394_FEATURE_HUE,             "HUE" },
   {    DC1394_FEATURE_SATURATION,      "SATURATION" },
   {    DC1394_FEATURE_GAMMA,           "GAMMA" },
   {    DC1394_FEATURE_SHUTTER,         "SHUTTER" },
   {    DC1394_FEATURE_GAIN,            "GAIN" },
   {    DC1394_FEATURE_IRIS,            "IRIS" },
   {    DC1394_FEATURE_FOCUS,           "FOCUS" },
   {    DC1394_FEATURE_TEMPERATURE,     "TEMPERATURE" },
   {    DC1394_FEATURE_TRIGGER,         "TRIGGER" },
   {    DC1394_FEATURE_TRIGGER_DELAY,   "TRIGGER_DELAY" },
   {    DC1394_FEATURE_WHITE_SHADING,   "WHITE_SHADING" },
   {    DC1394_FEATURE_FRAME_RATE,      "FRAME_RATE" },
   {    DC1394_FEATURE_ZOOM,            "ZOOM" },
   {    DC1394_FEATURE_PAN,             "PAN" },
   {    DC1394_FEATURE_TILT,            "TILT" },
   {    DC1394_FEATURE_OPTICAL_FILTER,  "OPTICAL_FILTER" },
   {    DC1394_FEATURE_CAPTURE_SIZE,    "CAPTURE_SIZE" },
   {    DC1394_FEATURE_CAPTURE_QUALITY, "CAPTURE_QUALITY" }
};


const EnumReference::dc1394_triggermode_entry EnumReference::m_arrTriggermodeList[]=
{  {    DC1394_TRIGGER_MODE_0,          "0" },
   {    DC1394_TRIGGER_MODE_1,          "1" },
   {    DC1394_TRIGGER_MODE_2,          "2" },
   {    DC1394_TRIGGER_MODE_3,          "3" },
   {    DC1394_TRIGGER_MODE_4,          "4" },
   {    DC1394_TRIGGER_MODE_5,          "5" },
   {    DC1394_TRIGGER_MODE_14,          "14" },
   {    DC1394_TRIGGER_MODE_15,          "15" }
};


const EnumReference::dc1394_triggersource_entry EnumReference::m_arrTriggersourceList[]=
{  {    DC1394_TRIGGER_SOURCE_0,        "0" },
   {    DC1394_TRIGGER_SOURCE_1,        "1" },
   {    DC1394_TRIGGER_SOURCE_2,        "2" },
   {    DC1394_TRIGGER_SOURCE_3,        "3" },
   {    DC1394_TRIGGER_SOURCE_SOFTWARE, "SW" }
};


QString EnumReference::LookupModeName( const dc1394video_mode_t eVal )
{
	unsigned int nNumOfItems = sizeof(m_arrModeList)/sizeof(dc1394_mode_entry);
	for ( unsigned int i=0; i<nNumOfItems; i++ )
	{
        if ( eVal == m_arrModeList[i].nVal )
		{
			return QString(m_arrModeList[i].szModeName);
		}
	}
	return QString("unknown");
}


QString EnumReference::LookupFramerateName( const dc1394framerate_t eVal )
{
	unsigned int nNumOfItems = sizeof(m_arrRateList)/sizeof(dc1394_framerate_entry);
	for ( unsigned int i=0; i<nNumOfItems; i++ )
	{
        if ( eVal == m_arrRateList[i].nVal )
		{
			return QString(m_arrRateList[i].szRateName);
		}
	}
	return QString("unknown");
}


QString EnumReference::LookupColorCodingName( const dc1394color_coding_t eVal )
{
    unsigned int nNumOfItems = sizeof(m_arrCodingList)/sizeof(dc1394_colorcoding_entry);
	for ( unsigned int i=0; i<nNumOfItems; i++ )
	{
        if ( eVal == m_arrCodingList[i].nVal )
		{
			return QString(m_arrCodingList[i].szCodingName);
		}
	}
	return QString("unknown");
}


QString EnumReference::LookupFeatureName( const dc1394feature_t eVal )
{
    unsigned int nNumOfItems = sizeof(m_arrFeatureList)/sizeof(dc1394_feature_entry);
    for ( unsigned int i=0; i<nNumOfItems; i++ )
    {
        if ( eVal == m_arrFeatureList[i].nVal )
        {
            return QString(m_arrFeatureList[i].szFeatureName);
        }
    }
    return QString("unknown");
}


QString EnumReference::LookupTriggerModeName( const dc1394trigger_mode_t eModeVal )
{
    unsigned int nNumOfItems = sizeof(m_arrTriggermodeList)/sizeof(dc1394_triggermode_entry);
    for ( unsigned int i=0; i<nNumOfItems; i++ )
    {
        if ( eModeVal == m_arrTriggermodeList[i].nVal )
        {
            return QString(m_arrTriggermodeList[i].szModeName);
        }
    }
    return QString("unknown");
}


QString EnumReference::LookupTriggerSourceName( const dc1394trigger_source_t eVal )
{
    unsigned int nNumOfItems = sizeof(m_arrTriggersourceList)/sizeof(dc1394_triggersource_entry);
    for ( unsigned int i=0; i<nNumOfItems; i++ )
    {
        if ( eVal == m_arrTriggersourceList[i].nVal )
        {
            return QString(m_arrTriggersourceList[i].szSourceName);
        }
    }
    return QString("unknown");
}
