/** \file featurecontrolfactory.cpp
 *  \brief This file contains the implementation of the factory class FeatureControlFactory.
 *
 *  \par license
 *  The cc1394 viewer application is licensed under the '3-clause'BSD License.
 *  Copyright (C) 2009, Allied Vision Technologies GmbH
 *  All rights reserved.
 *  Address: Taschenweg 2A, 07646 Stadtroda, Germany
 *  Email: info@alliedvisiontec.com
 *  Internet: www.alliedvisiontec.com
 *  Redistribution and use in source and binary forms, with or without modification, are permitted provided 
 *  that the following conditions are met:
 *     1. Redistributions of source code must retain the above copyright notice, this list of conditions and 
 *        the following disclaimer.
 *     2. Redistributions in binary form must reproduce the above copyright notice, this list of conditions 
 *        and the following disclaimer in the documentation and/or other materials provided with the 
 *        distribution.
 *     3. The name of Allied Vision Technologies GmbH may not be used to endorse or promote products derived 
 *        from this software without specific prior written permission.
 *  THIS SOFTWARE IS PROVIDED BY ALLIED VISION TECHNOLOGIES GMBH ''AS IS'' AND ANY EXPRESS OR IMPLIED WARRANTIES, 
 *  INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE 
 *  ARE DISCLAIMED. IN NO EVENT SHALL ALLIED VISION TECHNOLOGIES GMBH BE LIABLE FOR ANY DIRECT, INDIRECT, 
 *  INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF 
 *  SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON 
 *  ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) 
 *  ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

#include "featurecontrolfactory.h"
#include "featurecontrols/whitebalancecontrol.h"
#include "featurecontrols/extdshuttercontrol.h"
#include "featurecontrols/shuttercontrol.h"
#include "featurecontrols/aoicontrol.h"
#include "featurecontrols/colorcodingcontrol.h"
#include "featurecontrols/acquisitioncontrol.h"
#include "featurecontrols/videomodecontrol.h"
#include "featurecontrols/packetsizecontrol.h"
#include "featurecontrols/isospeedcontrol.h"
#include "featurecontrols/multishotcountcontrol.h"
#include "featurecontrols/frameratecontrol.h"
#include "featurecontrols/timebasecontrol.h"
#include "featurecontrols/autoshuttercontrol.h"
#include "featurecontrols/autogaincontrol.h"
#include "featurecontrols/testimagecontrol.h"
#include "featurecontrols/hsnrcontrol.h"
#include "featurecontrols/lutcontrol.h"
#include "featurecontrols/shadingcontrol.h"
#include "featurecontrols/hdrcontrol.h"
#include "featurecontrols/mirrorcontrol.h"
#include "featurecontrols/colorcorrectioncontrol.h"
#include "featurecontrols/iocontrol.h"
#include "featurecontrols/triggercontrol.h"
#include "featurecontrols/channeladjustcontrol.h"
#include "featurecontrols/channeladjustoffsetcontrol.h"
#include "featurecontrols/blemishcontrol.h"
#include "featurecontrols/dsnucontrol.h"
#include "featurecontrols/siscontrol.h"
#include "featurecontrols/framecountercontrol.h"
#include "featurecontrols/triggercountercontrol.h"
#include "featurecontrols/autofncaoicontrol.h"
#include "featurecontrols/ledcontrol.h"
#include "featurecontrols/globalresrelshuttercontrol.h"
#include "featurecontrols/lownoisebinningcontrol.h"
#include "featurecontrols/inputdebouncecontrol.h"
#include "featurecontrols/pwmoutcontrol.h"
#include "featurecontrols/lowsmearcontrol.h"
#include "featurecontrols/maxisosizecontrol.h"
#include "featurecontrols/userprofilecontrol.h"
#include "featurecontrols/defectpixelcontrol.h"

FeatureControlFactory::FeatureControlFactory( QWidget* pWidgetParent ) :
    m_pWidgetParent( pWidgetParent )
{
}


FeatureControlFactory::~FeatureControlFactory()
{
}


AbstractFeatureControl* FeatureControlFactory::createControl( QString strName )
{
    if( "brightness" == strName.toLower() )
    {
        return new StandardFeatureControl ( m_pWidgetParent, DC1394_FEATURE_BRIGHTNESS, QObject::tr( "Brightness" ) );
    }
    if( "exposure" == strName.toLower() )
    {
        return new StandardFeatureControl ( m_pWidgetParent, DC1394_FEATURE_EXPOSURE, QObject::tr( "Exposure" ) );
    }
    if( "sharpness" == strName.toLower() )
    {
        return new StandardFeatureControl ( m_pWidgetParent, DC1394_FEATURE_SHARPNESS, QObject::tr( "Sharpness" ) );
    }
    if( "hue" == strName.toLower() )
    {
        return new StandardFeatureControl ( m_pWidgetParent, DC1394_FEATURE_HUE, QObject::tr( "Hue" ) );
    }
    if( "saturation" == strName.toLower() )
    {
        return new StandardFeatureControl ( m_pWidgetParent, DC1394_FEATURE_SATURATION, QObject::tr( "Saturation" ) );
    }
    if( "shutter" == strName.toLower() )
    {
        return new ShutterControl ( m_pWidgetParent );
    }
    if( "gain" == strName.toLower() )
    {
        return new StandardFeatureControl ( m_pWidgetParent, DC1394_FEATURE_GAIN, QObject::tr( "Gain" ) );
    }
    if( "gamma" == strName.toLower() )
    {
        return new StandardFeatureControl ( m_pWidgetParent, DC1394_FEATURE_GAMMA, QObject::tr( "Gamma" ) );
    }
    if( "whitebalance" == strName.toLower() )
    {
        return new WhitebalanceControl( m_pWidgetParent );
    }
    if( "extdshutter" == strName.toLower() )
    {
        return new ExtdShutterControl( m_pWidgetParent );
    }
    if( "aoi" == strName.toLower() )
    {
        return new AoiControl( m_pWidgetParent );
    }
    if( "acquisition" == strName.toLower() )
    {
        return new AcquisitionControl( m_pWidgetParent );
    }
    if( "colorcoding" == strName.toLower() )
    {
        return new ColorCodingControl( m_pWidgetParent );
    }
    if( "videomode" == strName.toLower() )
    {
        return new VideoModeControl( m_pWidgetParent );
    }
    if( "packetsize" == strName.toLower() )
    {
        return new PacketSizeControl( m_pWidgetParent );
    }
    if( "isospeed" == strName.toLower() )
    {
        return new IsoSpeedControl( m_pWidgetParent );
    }
    if( "multishotcount" == strName.toLower() )
    {
        return new MultishotCountControl( m_pWidgetParent );
    }
    if( "framerate" == strName.toLower() )
    {
        return new FramerateControl( m_pWidgetParent );
    }
    if( "timebase" == strName.toLower() )
    {
        return new TimeBaseControl( m_pWidgetParent );
    }
    if( "autoshutter" == strName.toLower() )
    {
        return new AutoShutterControl( m_pWidgetParent );
    }
    if( "autogain" == strName.toLower() )
    {
        return new AutoGainControl( m_pWidgetParent );
    }
    if( "testimage" == strName.toLower() )
    {
        return new TestImageControl( m_pWidgetParent );
    }
    if( "hsnr" == strName.toLower() )
    {
        return new HsnrControl( m_pWidgetParent );
    }
    if( "lut" == strName.toLower() )
    {
        return new LutControl( m_pWidgetParent );
    }
    if( "shading" == strName.toLower() )
    {
        return new ShadingControl( m_pWidgetParent );
    }
    if( "hdr" == strName.toLower() )
    {
        return new HdrControl( m_pWidgetParent );
    }
    if( "mirror" == strName.toLower() )
    {
        return new MirrorControl( m_pWidgetParent );
    }
    if( "colorcorrection" == strName.toLower() )
    {
        return new ColorCorrectionControl( m_pWidgetParent );
    }
    if( "io" == strName.toLower() )
    {
        return new IoControl( m_pWidgetParent );
    }
    if( "trigger" == strName.toLower() )
    {
        return new TriggerControl( m_pWidgetParent );
    }
    if( "triggerdelay" == strName.toLower() )
    {
        return new StandardFeatureControl( m_pWidgetParent, DC1394_FEATURE_TRIGGER_DELAY, QObject::tr( "Trigger Delay" ) );
    }
    if( "channeladjustgain" == strName.toLower() )
    {
        return new ChannelAdjustControl( m_pWidgetParent );
    }
    if( "channeladjustoffset" == strName.toLower() )
    {
        return new ChannelAdjustOffsetControl( m_pWidgetParent );
    }
    if( "blemish" == strName.toLower() )
    {
        return new BlemishControl( m_pWidgetParent );
    }
    if( "dsnu" == strName.toLower() )
    {
        return new DsnuControl( m_pWidgetParent );
    }
    if( "sis" == strName.toLower() )
    {
        return new SisControl( m_pWidgetParent );
    }
    if( "framecounter" == strName.toLower() )
    {
        return new FrameCounterControl( m_pWidgetParent );
    }
    if( "triggercounter" == strName.toLower() )
    {
        return new TriggerCounterControl( m_pWidgetParent );
    }
    if( "autofncaoi" == strName.toLower() )
    {
        return new AutofncAoiControl( m_pWidgetParent );
    }
    if( "globalresrelshutter" == strName.toLower() )
    {
        return new GlobalResRelShutterControl( m_pWidgetParent );
    }
    if( "led" == strName.toLower() )
    {
        return new LedControl( m_pWidgetParent );
    }
    if( "lownoisebinning" == strName.toLower() )
    {
        return new LowNoiseBinningControl( m_pWidgetParent );
    }
    if( "inputdebounce" == strName.toLower() )
    {
        return new InputDebounceControl( m_pWidgetParent );
    }
    if( "pwmout" == strName.toLower() )
    {
        return new PwmOutControl( m_pWidgetParent );
    }
    if( "lowsmear" == strName.toLower() )
    {
        return new LowSmearControl( m_pWidgetParent );
    }
    if( "maxisosize" == strName.toLower() )
    {
        return new MaxIsoSizeControl( m_pWidgetParent );
    }
    if( "userprofiles" == strName.toLower() )
    {
        return new UserProfileControl( m_pWidgetParent );
    }
    if( "defectpixel" == strName.toLower() )
    {
        return new DefectPixelControl( m_pWidgetParent );
    }
    return NULL;
}
