/** \file areaselection.h
 *  \brief This file contains the definition of the AreaSelection class.
 *         (helper control class for visual 2D area selection)
 *
 *  \par license
 *  The cc1394 viewer application is licensed under the '3-clause'BSD License.
 *  Copyright (C) 2009, Allied Vision Technologies GmbH
 *  All rights reserved.
 *  Address: Taschenweg 2A, 07646 Stadtroda, Germany
 *  Email: info@alliedvisiontec.com
 *  Internet: www.alliedvisiontec.com
 *  Redistribution and use in source and binary forms, with or without modification, are permitted provided 
 *  that the following conditions are met:
 *     1. Redistributions of source code must retain the above copyright notice, this list of conditions and 
 *        the following disclaimer.
 *     2. Redistributions in binary form must reproduce the above copyright notice, this list of conditions 
 *        and the following disclaimer in the documentation and/or other materials provided with the 
 *        distribution.
 *     3. The name of Allied Vision Technologies GmbH may not be used to endorse or promote products derived 
 *        from this software without specific prior written permission.
 *  THIS SOFTWARE IS PROVIDED BY ALLIED VISION TECHNOLOGIES GMBH ''AS IS'' AND ANY EXPRESS OR IMPLIED WARRANTIES, 
 *  INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE 
 *  ARE DISCLAIMED. IN NO EVENT SHALL ALLIED VISION TECHNOLOGIES GMBH BE LIABLE FOR ANY DIRECT, INDIRECT, 
 *  INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF 
 *  SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON 
 *  ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) 
 *  ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */


#ifndef AREASELECTION_H
#define AREASELECTION_H

#include <QFrame>
#include <QRubberBand>

typedef enum
{
    EDIT_NONE,
    EDIT_TOPLEFT,
    EDIT_TOPRIGHT,
    EDIT_BOTTOMLEFT,
    EDIT_BOTTOMRIGHT,
    EDIT_TOP,
    EDIT_RIGHT,
    EDIT_LEFT,
    EDIT_BOTTOM,
    EDIT_MOVE
} E_AREA_EDIT_MODE;

class AreaSelection : public QFrame
{
    Q_OBJECT
    Q_PROPERTY ( int m_nMaxAreaWidth READ maxAreaWidth WRITE setMaxAreaWidth )
    Q_PROPERTY ( int m_nMaxAreaHeight READ maxAreaHeight WRITE setMaxAreaHeight )
    Q_PROPERTY ( int m_nAreaLeft READ areaLeft WRITE setAreaLeft )
    Q_PROPERTY ( int m_nAreaTop READ areaTop WRITE setAreaTop )
    Q_PROPERTY ( int m_nAreaWidth READ areaWidth WRITE setAreaWidth )
    Q_PROPERTY ( int m_nAreaHeight READ areaHeight WRITE setAreaHeight )
    Q_PROPERTY ( bool m_bAreaSizeFixed READ areaSizeFixed WRITE setAreaSizeFixed )

public:
    AreaSelection( QWidget* pParent );
    virtual int heightForWidth ( int w ) const;
    void init();

    /* property access */
    int  maxAreaWidth(void) { return m_nMaxAreaWidth; }
    void setMaxAreaWidth(int nVal) { m_nMaxAreaWidth = nVal; }
    int  maxAreaHeight(void) { return m_nMaxAreaHeight; }
    void setMaxAreaHeight(int nVal) { m_nMaxAreaHeight = nVal; }

    int  areaLeft(void) { return m_nAreaLeft; }
    void setAreaLeft(int nVal);
    int  areaTop(void) { return m_nAreaTop; }
    void setAreaTop(int nVal);
    int  areaWidth(void) { return m_nAreaWidth; }
    void setAreaWidth(int nVal);
    int  areaHeight(void) { return m_nAreaHeight; }
    void setAreaHeight(int nVal);

    bool areaSizeFixed(void) { return m_bAreaSizeFixed; }
    void setAreaSizeFixed(bool bFixed) { m_bAreaSizeFixed = bFixed; }

signals:
    void areaChanged(void);


protected:
    virtual void resizeEvent ( QResizeEvent * event );
    virtual void mouseMoveEvent( QMouseEvent * event );
    virtual void mousePressEvent( QMouseEvent * event );
    virtual void mouseReleaseEvent( QMouseEvent * event );

private:
    void adjustRubberband();
    QRubberBand* m_pAreaRubberBand;
    E_AREA_EDIT_MODE interpretPosition( const QPoint* pos ) const;
    E_AREA_EDIT_MODE m_eCurrentEditMode;
    QPoint  m_Offset; /* Position where the mouse button has been pressed down */
    QPoint  m_StartPos;
    QSize   m_StartSize;
    int m_nMaxAreaWidth;
    int m_nMaxAreaHeight;
    int m_nAreaLeft;
    int m_nAreaTop;
    int m_nAreaWidth;
    int m_nAreaHeight;

    bool m_bAreaSizeFixed;
};

#endif // AREASELECTION_H
