/** \file autofncaoicontrol.h
 *  \brief This file contains the definition of the feature control class AutofncAoiControl.
 *
 *  \par license
 *  The cc1394 viewer application is licensed under the '3-clause'BSD License.
 *  Copyright (C) 2009, Allied Vision Technologies GmbH
 *  All rights reserved.
 *  Address: Taschenweg 2A, 07646 Stadtroda, Germany
 *  Email: info@alliedvisiontec.com
 *  Internet: www.alliedvisiontec.com
 *  Redistribution and use in source and binary forms, with or without modification, are permitted provided 
 *  that the following conditions are met:
 *     1. Redistributions of source code must retain the above copyright notice, this list of conditions and 
 *        the following disclaimer.
 *     2. Redistributions in binary form must reproduce the above copyright notice, this list of conditions 
 *        and the following disclaimer in the documentation and/or other materials provided with the 
 *        distribution.
 *     3. The name of Allied Vision Technologies GmbH may not be used to endorse or promote products derived 
 *        from this software without specific prior written permission.
 *  THIS SOFTWARE IS PROVIDED BY ALLIED VISION TECHNOLOGIES GMBH ''AS IS'' AND ANY EXPRESS OR IMPLIED WARRANTIES, 
 *  INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE 
 *  ARE DISCLAIMED. IN NO EVENT SHALL ALLIED VISION TECHNOLOGIES GMBH BE LIABLE FOR ANY DIRECT, INDIRECT, 
 *  INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF 
 *  SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON 
 *  ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) 
 *  ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */


#ifndef AUTOFNCAOICONTROL_H
#define AUTOFNCAOICONTROL_H

#include "abstractfeaturecontrol.h"
#include "ui_autofncaoicontrol.h"

#include <dc1394/dc1394.h>


class AutofncAoiControl : public AbstractFeatureControl, private Ui_AutofncAoiControl
{
    Q_OBJECT
public:
    AutofncAoiControl( QWidget* pParent );

    ~AutofncAoiControl();

    void setCamera( Dc1394Camera*      pCamera, 
                    AcquisitionThread* pThread );
    void pollStateFromCamera();

public slots:
    virtual void onStateChangedByTwinControl(void);

    void onVideoModeSwitched_autoconnect();
    void onImageSizeChanged_autoconnect( int nImgWidth, int nImgHeight );

private slots:
    void onAreaChange  ();
    void onLeftChange  ( int nValue );
    void onTopChange   ( int nValue );
    void onWidthChange ( int nValue );
    void onHeightChange( int nValue );
    void onEnableClicked( bool bChecked );
    void onShowAreaClicked( bool bChecked );

signals:
    void AutofncAoiChanged( void );

private:
    void adjustSpinboxRanges();

    int m_nMaxX;
    int m_nMaxY;

    bool m_bEnable;
    bool m_bShowArea;

    int m_nXUnit;
    int m_nYUnit;

    int m_nLeft;
    int m_nTop;
    int m_nWidth;
    int m_nHeight;
};

#endif // AOICONTROL_H
