/** \file framecountercontrol.cpp
 *  \brief This file contains the implementation of the feature control class FrameCounterControl.
 *
 *  \par license
 *  The cc1394 viewer application is licensed under the '3-clause'BSD License.
 *  Copyright (C) 2009, Allied Vision Technologies GmbH
 *  All rights reserved.
 *  Address: Taschenweg 2A, 07646 Stadtroda, Germany
 *  Email: info@alliedvisiontec.com
 *  Internet: www.alliedvisiontec.com
 *  Redistribution and use in source and binary forms, with or without modification, are permitted provided
 *  that the following conditions are met:
 *     1. Redistributions of source code must retain the above copyright notice, this list of conditions and
 *        the following disclaimer.
 *     2. Redistributions in binary form must reproduce the above copyright notice, this list of conditions
 *        and the following disclaimer in the documentation and/or other materials provided with the
 *        distribution.
 *     3. The name of Allied Vision Technologies GmbH may not be used to endorse or promote products derived
 *        from this software without specific prior written permission.
 *  THIS SOFTWARE IS PROVIDED BY ALLIED VISION TECHNOLOGIES GMBH ''AS IS'' AND ANY EXPRESS OR IMPLIED WARRANTIES,
 *  INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 *  ARE DISCLAIMED. IN NO EVENT SHALL ALLIED VISION TECHNOLOGIES GMBH BE LIABLE FOR ANY DIRECT, INDIRECT,
 *  INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 *  SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON
 *  ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 *  ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */


#include "framecountercontrol.h"

FrameCounterControl::FrameCounterControl( QWidget* pParent )
 : AbstractFeatureControl( pParent )
 , Ui_FrameCounterControl()
{
    setupUi ( this );

    connect( m_pRefreshCheckBox, SIGNAL( clicked(bool)), this, SLOT( onRefreshClicked(bool)) );
    connect( m_pResetButton, SIGNAL( clicked() ), this, SLOT( onResetClicked() ) );

    m_bRefreshRequired = false;
    m_pRefreshCheckBox->setChecked(false);
}

FrameCounterControl::~FrameCounterControl()
{
}


void FrameCounterControl::setCamera( Dc1394Camera*      pCamera,
                                     AcquisitionThread* /*pThread*/ )
{
    m_pCamObject = pCamera;

    if( NULL == m_pCamObject )
    {
        setEnabled( false );
        return;
    }

    /* check feature support */
    if ( DC1394_FALSE == pCamera->smartFeatureInquiry()->FrameCounter )
    {
        /* Frame Counter is not supported */
        setEnabled(false);
        return;
    }

    setEnabled(true);
    pollStateFromCamera();
}


void FrameCounterControl::pollStateFromCamera()
{
    dc1394error_t   eRet;
    uint32_t        nVal;

    eRet = dc1394_avt_get_frame_counter( m_pCamObject->psCamInternal(), m_pCamObject->smartFeatureInquiry(), &nVal );
    LOGFCALL_LIBDC ( "dc1394_avt_get_frame_counter", eRet );

    m_pValueLineEdit->setText(QString::number(nVal));
}


void FrameCounterControl::onStateChangedByTwinControl(void)
{
}

void FrameCounterControl::onRefreshClicked( bool bChecked )
{
    m_bRefreshRequired = bChecked;
}

void FrameCounterControl::onResetClicked()
{
    dc1394error_t   eRet;
    eRet = dc1394_avt_reset_frame_counter( m_pCamObject->psCamInternal(), m_pCamObject->smartFeatureInquiry() );
    LOGFCALL_LIBDC ( "dc1394_avt_reset_frame_counter", eRet );

    pollStateFromCamera();
}
