/** \file isospeedcontrol.cpp
 *  \brief This file contains the implementation of the feature control class IsoSpeedControl.
 *
 *  \par license
 *  The cc1394 viewer application is licensed under the '3-clause'BSD License.
 *  Copyright (C) 2009, Allied Vision Technologies GmbH
 *  All rights reserved.
 *  Address: Taschenweg 2A, 07646 Stadtroda, Germany
 *  Email: info@alliedvisiontec.com
 *  Internet: www.alliedvisiontec.com
 *  Redistribution and use in source and binary forms, with or without modification, are permitted provided 
 *  that the following conditions are met:
 *     1. Redistributions of source code must retain the above copyright notice, this list of conditions and 
 *        the following disclaimer.
 *     2. Redistributions in binary form must reproduce the above copyright notice, this list of conditions 
 *        and the following disclaimer in the documentation and/or other materials provided with the 
 *        distribution.
 *     3. The name of Allied Vision Technologies GmbH may not be used to endorse or promote products derived 
 *        from this software without specific prior written permission.
 *  THIS SOFTWARE IS PROVIDED BY ALLIED VISION TECHNOLOGIES GMBH ''AS IS'' AND ANY EXPRESS OR IMPLIED WARRANTIES, 
 *  INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE 
 *  ARE DISCLAIMED. IN NO EVENT SHALL ALLIED VISION TECHNOLOGIES GMBH BE LIABLE FOR ANY DIRECT, INDIRECT, 
 *  INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF 
 *  SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON 
 *  ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) 
 *  ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */


#include "isospeedcontrol.h"

IsoSpeedControl::IsoSpeedControl( QWidget* pParent ) :
        AbstractFeatureControl( pParent)
        , Ui_IsoSpeedControl()
{
    setupUi ( this );

    connect( m_pComboBox, SIGNAL( currentIndexChanged(int) ), this, SLOT( onChange(int) ) );
}


IsoSpeedControl::~IsoSpeedControl()
{
    ;
}


void IsoSpeedControl::setCamera( Dc1394Camera*      pCamera, 
                                 AcquisitionThread* /*pThread*/ )
{
    m_pCamObject = pCamera;

    if( NULL == m_pCamObject )
    {
        setEnabled( false );
        return;
    }

    m_pComboBox->blockSignals( true );
    m_pComboBox->clear();
    m_pComboBox->addItem( "S100", QVariant ( ( uint ) DC1394_ISO_SPEED_100 ) );
    m_pComboBox->addItem( "S200", QVariant ( ( uint ) DC1394_ISO_SPEED_200 ) );
    m_pComboBox->addItem( "S400", QVariant ( ( uint ) DC1394_ISO_SPEED_400 ) );
    if ( m_pCamObject->b1394BModeSupported() )
    {
        m_pComboBox->addItem( "S800", QVariant ( ( uint ) DC1394_ISO_SPEED_800 ) );
    }
    m_pComboBox->blockSignals( false );

    pollStateFromCamera();
    setEnabled(true);
}


void IsoSpeedControl::onStateChangedByTwinControl(void)
{
    IsoSpeedControl* pSender = qobject_cast<IsoSpeedControl*> ( sender() );
    if( NULL == pSender )
    {
        return;
    }

    m_pComboBox->setCurrentIndex( pSender->m_pComboBox->currentIndex() );
}


void IsoSpeedControl::pollStateFromCamera()
{
    if( NULL == m_pCamObject )
    {
        return;
    }

    m_pComboBox->setCurrentIndex( m_pComboBox->findData ( QVariant ( m_pCamObject->getIsoSpeed() ) ) );
}


void IsoSpeedControl::setAcquisitionState( bool bActive )
{
    m_pComboBox->setEnabled( !bActive );
}


void IsoSpeedControl::onChange( int nIndex )
{
    dc1394speed_t eSpeed = (dc1394speed_t) m_pComboBox->itemData( nIndex ).toInt();
    if ( m_pCamObject->getIsoSpeed() == eSpeed )
    {
        return;
    }

    m_pCamObject->setIsoSpeed(eSpeed);

    emit IsoSpeedChanged();
    emit featureStateChanged();
}
