/** \file videomodecontrol.cpp
 *  \brief This file contains the implementation of the feature control class VideoModeControl.
 *
 *  \par license
 *  The cc1394 viewer application is licensed under the '3-clause'BSD License.
 *  Copyright (C) 2009, Allied Vision Technologies GmbH
 *  All rights reserved.
 *  Address: Taschenweg 2A, 07646 Stadtroda, Germany
 *  Email: info@alliedvisiontec.com
 *  Internet: www.alliedvisiontec.com
 *  Redistribution and use in source and binary forms, with or without modification, are permitted provided 
 *  that the following conditions are met:
 *     1. Redistributions of source code must retain the above copyright notice, this list of conditions and 
 *        the following disclaimer.
 *     2. Redistributions in binary form must reproduce the above copyright notice, this list of conditions 
 *        and the following disclaimer in the documentation and/or other materials provided with the 
 *        distribution.
 *     3. The name of Allied Vision Technologies GmbH may not be used to endorse or promote products derived 
 *        from this software without specific prior written permission.
 *  THIS SOFTWARE IS PROVIDED BY ALLIED VISION TECHNOLOGIES GMBH ''AS IS'' AND ANY EXPRESS OR IMPLIED WARRANTIES, 
 *  INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE 
 *  ARE DISCLAIMED. IN NO EVENT SHALL ALLIED VISION TECHNOLOGIES GMBH BE LIABLE FOR ANY DIRECT, INDIRECT, 
 *  INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF 
 *  SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON 
 *  ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) 
 *  ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */


#include "videomodecontrol.h"


VideoModeControl::VideoModeControl( QWidget* pParent )
 : AbstractFeatureControl( pParent )
 , Ui_VideoModeControl()
{
    setupUi ( this );

    connect( m_pComboBox, SIGNAL( currentIndexChanged(int) ), this, SLOT( onComboBoxChange(int) ) );
}


VideoModeControl::~VideoModeControl()
{
}


void VideoModeControl::setCamera( Dc1394Camera*      pCamera, 
                                  AcquisitionThread* pThread )
{
    m_pCamObject = pCamera;

    if( NULL == m_pCamObject )
    {
        setEnabled( false );
        return;
    }

    UpdateList();
    m_pComboBox->setCurrentIndex ( m_pComboBox->findData ( QVariant ( m_pCamObject->getVideoMode() ) ) );
    setEnabled(true);

    m_pComboBox->setEnabled( !pThread->isRunning() );
}


void VideoModeControl::UpdateList()
{
    dc1394error_t eRet;

    m_pComboBox->blockSignals ( true );

    // fill video mode combo box
    m_pComboBox->blockSignals ( true );
    m_pComboBox->clear();
    QVector<cc1394_modeitem> vecModelist;
    eRet = m_pCamObject->getModeList ( vecModelist );
    foreach ( cc1394_modeitem sModeitem, vecModelist )
    {
        m_pComboBox->addItem ( sModeitem.m_strName, QVariant ( ( uint ) sModeitem.m_eMode ) );
    }

    m_pComboBox->blockSignals ( false );
}


void VideoModeControl::onStateChangedByTwinControl(void)
{
    VideoModeControl* pSender = qobject_cast<VideoModeControl*> ( sender() );
    if( NULL == pSender )
    {
        return;
    }

    m_pComboBox->setCurrentIndex( pSender->m_pComboBox->currentIndex() );
}


void VideoModeControl::setAcquisitionState( bool bActive )
{
    m_pComboBox->setEnabled( !bActive );
}


void VideoModeControl::onComboBoxChange( int nIndex )
{
    if( NULL == m_pCamObject )
    {
        return;
    }

    if ( m_pCamObject->getVideoMode() != (dc1394video_mode_t) m_pComboBox->itemData( nIndex ).toInt() )
    {
        m_pCamObject->setVideoMode( (dc1394video_mode_t) m_pComboBox->itemData( nIndex ).toInt() );

        emit VideoModeSwitched();
        emit featureStateChanged();
    }
}

void VideoModeControl::pollStateFromCamera()
{
    if( NULL == m_pCamObject )
    {
        return;
    }

    m_pComboBox->setCurrentIndex ( m_pComboBox->findData ( QVariant ( m_pCamObject->getVideoMode() ) ) );
}





